@@ -747,44 +747,3 @@ Surv.CI=function(t,x,boot.par,Rawdata,n_subject,n_within,r,CI.lev=0.95,n_quad=30
 }
 
 
-dignest.fun=function(Rawdata,n_subject.raw,n_within.raw,r,n_quad=30,lambda=0,Cauchy.pen=TRUE,tolerance=1e-2,
-                     knots.num=2,degree=2,scale.numr=TRUE,cure.reg=TRUE,clustering=TRUE){
-  myrules=.ghrules(n_quad,normalized=FALSE)
-  myrules=as.matrix(myrules[[n_quad]])
-  if(scale.numr==TRUE){
-    Rawdata=.Datascale(Rawdata,n_subject.raw,n_within.raw)
-    n_tooth.cov=n_within.raw
-    n_subject.cov=n_subject.raw
-    totaldata=.Data.trans(Rawdata,n_subject.cov,n_tooth.cov)
-  }
-  else{
-    totaldata=.Data.trans(Rawdata,n_subject.raw,n_within.raw)
-    n_tooth.cov=n_within.raw
-    n_subject.cov=n_subject.raw
-  }
-  n=totaldata[[1]]
-  ni=totaldata[[2]]
-  C=totaldata[[3]]
-  Delta=totaldata[[4]]
-  X=totaldata[[5]]
-  Z=totaldata[[6]]
-  minCSTime=min(Rawdata[,2])
-  maxCSTime=max(Rawdata[,2])
-  blC <- list()
-  length(blC) <- n
-  knots <- seq(0,1  , length.out = (knots.num + 2))
-  knots=knots[3:length(knots)-1]
-  
-  for (i in 1:n) {
-    blC[[i]]=t(splines2::ibs((C[[i]]-(minCSTime-0.1))/(maxCSTime-minCSTime+0.2),knots = knots,degree=degree
-                             ,Boundary.knots = c(0,1),intercept = TRUE))
-  }
-  
-  par.est=.EMest(X,Z,Delta,n,ni,C,r,n_quad,lambda,tolerance,blC,myrules,Cauchy.pen,clustering)
-  directresult=optim(par=par.est,fn=testquadrature1,rules=myrules,Delta=Delta,X=X,Z=Z,n=n,ni=ni,
-                     r=r,blC=blC,betadim=n_within.raw,gammadim=n_subject.raw,weight=rep(1,n),hessian = 1)
-  Deltamatrix=.jacob_weight(rep(1,n),par.est,myrules,Delta,X,Z,n,ni,r,blC,betadim=n_within.raw,gammadim=n_subject.raw)
-  Mmatrix=t(Deltamatrix)%*%solve(directresult$hessian)%*%Deltamatrix
-  return(Mmatrix)
-  
-}
